"use strict";

var _electron = require("electron");

// Alert module
_electron.ipcMain.handle('react-native-show-alert', async (event, options) => {
  const window = _electron.BrowserWindow.fromWebContents(event.sender);

  const {
    response
  } = await _electron.dialog.showMessageBox(window, options);
  return response;
}); // Linking module


const trackedAppOpenURL = new Set();

function onOpenURL(_, url) {
  for (const tracked of trackedAppOpenURL) {
    const target = _electron.BrowserWindow.fromWebContents(tracked);

    if (target == null) {
      trackedAppOpenURL.delete(tracked);
    } else {
      target.send('react-native-app-open-url', url);
    }
  }
}

_electron.ipcMain.handle('react-native-get-initial-url', async () => {
  return process.argv[1];
});

_electron.ipcMain.handle('react-native-open-url', async (event, url) => {
  await _electron.shell.openExternal(url);
}); // Internal


_electron.ipcMain.on('react-native-supported', event => {
  event.returnValue = true;
});

_electron.ipcMain.on('newListener', event => {
  if (event === 'react-native-app-open-url') {
    if (trackedAppOpenURL.size === 0) {
      _electron.app.on('open-url', onOpenURL);
    }

    trackedAppOpenURL.add(event.sender);
  }
});

_electron.ipcMain.on('removeListener', event => {
  if (event === 'react-native-app-open-url') {
    trackedAppOpenURL.delete(event.sender);

    if (trackedAppOpenURL.size === 0) {
      _electron.app.off('open-url', onOpenURL);
    }
  }
});