"use strict";

var _electron = require("electron");

var _events = _interopRequireDefault(require("events"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const ipc = new _events.default();
ipc.on('newListener', event => {
  if (!_electron.ipcRenderer.sendSync('react-native-supported')) {
    console.warn('Could not attach React Native event listener, make sure the "react-native-electron/main" module is imported in your main process.');
  }

  if (ipc.listenerCount(event) === 0) {
    _electron.ipcRenderer.on(`react-native-${event}`, (...args) => {
      ipc.emit(event, ...args);
    });

    _electron.ipcRenderer.emit(`react-native-on-${event}`);
  }
});
ipc.on('removeListener', event => {
  if (ipc.listenerCount(event) === 0) {
    _electron.ipcRenderer.off(`react-native-${event}`);

    _electron.ipcRenderer.emit(`react-native-off-${event}`);
  }
});

async function getInitialURL() {
  return await _electron.ipcRenderer.invoke('react-native-get-initial-url');
}

async function openURL(url) {
  return await _electron.ipcRenderer.invoke('react-native-open-url', url);
}

async function showAlert(config) {
  return await _electron.ipcRenderer.invoke('react-native-show-alert', config);
}

window.ReactNativeElectron = {
  ipc,
  getInitialURL,
  openURL,
  showAlert
};